@@ -1,6 +1,6 @@
 
 package MIME::Charset;
-use 5.005;
+use v5.8;
 
 =head1 NAME
 
@@ -8,101 +8,50 @@ MIME::Charset - Charset Informations for MIME
 
 =head1 SYNOPSIS
 
-Getting charset informations:
+    use MIME::Charset qw(:all);
 
-    use MIME::Charset qw(:info);
+    # Convert text for message body.
+    ($converted, $charset, $encoding) =
+        body_encode(
+            "\xc9\xc2\xc5\xaa\xc0\xde\xc3\xef\xc5\xaa".
+            "\xc7\xd1\xca\xaa\xbd\xd0\xce\xcf\xb4\xef",
+            "euc-jp");
 
-    $benc = body_encoding("iso-8859-2"); # "Q"
-    $cset = canonical_charset("ANSI X3.4-1968"); # "US-ASCII"
-    $henc = header_encoding("utf-8"); # "S"
-    $cset = output_charset("shift_jis"); # "ISO-2022-JP"
-
-Translating text data:
-
-    use MIME::Charset qw(:trans);
-
-    ($text, $charset, $encoding) =
+    # Convert text for message header.
+    ($converted, $charset, $encoding) =
         header_encode(
            "\xc9\xc2\xc5\xaa\xc0\xde\xc3\xef\xc5\xaa".
            "\xc7\xd1\xca\xaa\xbd\xd0\xce\xcf\xb4\xef",
            "euc-jp");
-    # ...returns (<converted>, "ISO-2022-JP", "B");
-
-    ($text, $charset, $encoding) =
-        body_encode(
-            "Collectioneur path\xe9tiquement ".
-            "\xe9clectique de d\xe9chets",
-            "latin1");
-    # ...returns (<original>, "ISO-8859-1", "QUOTED-PRINTABLE");
-
-    $len = encoded_header_len(
-        "Perl\xe8\xa8\x80\xe8\xaa\x9e", "b", "utf-8"); # 28
-
-Manipulating module defaults:
-
-    use MIME::Charset;
-
-    MIME::Charset::alias("csEUCKR", "euc-kr");
-    MIME::Charset::default("iso-8859-1");
-    MIME::Charset::fallback("us-ascii");
 
 =head1 DESCRIPTION
 
 MIME::Charset provides informations about character sets used for
 MIME messages on Internet.
 
-=head2 DEFINITIONS
-
-The B<charset> is ``character set'' used in MIME to refer to a
-method of converting a sequence of octets into a sequence of characters.
-It includes both concepts of ``coded character set'' (CCS) and
-``character encoding scheme'' (CES) of ISO/IEC.
-
-The B<encoding> is that used in MIME to refer to a method of representing
-a body part or a header body as sequence(s) of printable US-ASCII
-characters.
-
 =over 4
 
 =cut
 
+use vars qw(@ISA $VERSION);
 use strict;
-use vars qw(@ISA $VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS);
-use Exporter;
-@ISA = qw(Exporter);
-@EXPORT = qw(body_encoding canonical_charset header_encoding output_charset
-	     body_encode encoded_header_len header_encode);
-@EXPORT_OK = qw(alias default fallback recommended);
-%EXPORT_TAGS = (
-		"info" => [qw(body_encoding header_encoding
-			      canonical_charset output_charset)],
-		"trans" =>[ qw(body_encode encoded_header_len
-			       header_encode)],
-		);
+require Exporter;
+my @ISA = qw(Exporter);
+my @EXPORT_OK = qw(body_encoding canonical_charset header_encoding
+		   output_charset body_encode header_encode
+		   alias default fallback recommended);
 use Carp qw(croak);
 
-use constant USE_ENCODE => ($] >= 5.008001)? 'Encode': '';
+use Encode;
 
-my @ENCODE_SUBS = qw(FB_CROAK FB_PERLQQ FB_HTMLCREF FB_XMLCREF
-		     decode encode from_to is_utf8 resolve_alias);
-if (USE_ENCODE) {
-    eval "use ".USE_ENCODE." \@ENCODE_SUBS;";
-} else {
-    require MIME::Charset::_Compat;
-    for my $sub (@ENCODE_SUBS) {
-	no strict "refs";
-	*{$sub} = \&{"MIME::Charset::_Compat::$sub"};
-    }
-}
-
-$VERSION = '0.04.1';
+$VERSION = '0.01';
 
 ######## Private Attributes ########
 
 my $DEFAULT_CHARSET = 'US-ASCII';
 my $FALLBACK_CHARSET = 'UTF-8';
 
-# This table was borrwed from Python email package.
+# This table is borrwed from Python email package.
 
 my %CHARSETS = (# input		    header enc body enc output conv
 		'ISO-8859-1' =>		['Q',	'Q',	undef],
@@ -160,7 +109,7 @@ my @ISO2022_SEQ = (# escape seq	possible charset
 		   ["\033\$(D",	"ISO-2022-JP"],	# RFC 2237 (note*)
 		   # Folloing sequences are less commonly used.
 		   ["\033\$)C",	"ISO-2022-KR"],	# RFC 1557
-		   ["\033\$)A",	"ISO-2022-CN"], # RFC 1922
+		   ["\033\$)A",	"ISO-2022-CN"], # ditto
 		   ["\033\$A",	"ISO-2022-CN"], # ditto (nonstandard)
 		   ["\033\$)G",	"ISO-2022-CN"], # ditto
 		   ["\033\$*H",	"ISO-2022-CN"], # ditto
@@ -170,9 +119,9 @@ my @ISO2022_SEQ = (# escape seq	possible charset
 
 		   # note*: This RFC defines ISO-2022-JP-1, superset of
 		   # ISO-2022-JP.  But that charset name is rarely used.
-		   # OTOH many of codecs for ISO-2022-JP recognize this
-		   # sequence so that comatibility with EUC-JP will be
-		   # guaranteed.
+		   # OTOH many of decoders/encoders for ISO-2022-JP
+		   # recognize this sequence so that comatibility with EUC-JP
+		   # will be guaranteed.
 
 ######## Private Constants ########
 
@@ -193,7 +142,7 @@ my $ISO2022RE = qr{
 
 Get recommended transfer-encoding of CHARSET for message body.
 
-Returned value will be one of C<"B"> (BASE64), C<"Q"> (QUOTED-PRINTABLE) or
+Returned value is one of C<"B"> (BASE64), C<"Q"> (QUOTED-PRINTABLE) or
 C<undef> (might not be transfer-encoded; either 7BIT or 8BIT).  This may
 not be same as encoding for message header.
 
@@ -214,7 +163,7 @@ Get canonical name for charset CHARSET.
 sub canonical_charset($) {
     my $charset = shift;
     return undef unless $charset;
-    my $cset = resolve_alias($charset) || $charset;
+    my $cset = Encode::resolve_alias($charset) || $charset;
     return $CHARSET_ALIASES{uc($cset)} || uc($cset);
 }
 
@@ -222,7 +171,7 @@ sub canonical_charset($) {
 
 Get recommended encoding scheme of CHARSET for message header.
 
-Returned value will be one of C<"B">, C<"Q">, C<"S"> (shorter one of either)
+Returned value is one of C<"B">, C<"Q">, C<"S"> (shorter one of either)
 or C<undef> (might not be encoded).  This may not be same as encoding
 for message body.
 
@@ -236,12 +185,8 @@ sub header_encoding($) {
 
 =item output_charset CHARSET
 
-Get a charset which is compatible with given CHARSET and is recommended
-to be used for MIME messages on Internet (if it is known by this module).
-
-When Unicode/multibyte support is disabled (see L<"USE_ENCODE">),
-this function will simply
-return the result of L<"canonical_charset">.
+Get a charset compatible with given CHARSET which is recommended to be
+used for MIME messages on Internet (if it is known by this package).
 
 =cut
 
@@ -255,20 +200,17 @@ sub output_charset($) {
 
 =item body_encode STRING, CHARSET [, OPTS]
 
-Get converted (if needed) data of STRING and recommended transfer-encoding
-of that data for message body.  CHARSET is the charset by which STRING
+Get converted (if needed) data and recommended transfer-encoding of
+that data for message body.  CHARSET is the charset by which STRING
 is encoded.
 
-OPTS may accept following key-value pairs.
-B<NOTE>:
-When Unicode/multibyte support is disabled (see L<"USE_ENCODE">),
-conversion will not be performed.  So these options do not have any effects.
+OPTS may accept following key-value pairs:
 
 =over 4
 
 =item Replacement => REPLACEMENT
 
-Specifies error handling scheme.  See L<"ERROR HANDLING">.
+Specifies error handling scheme. See L<ERROR HANDLING>.
 
 =item Detect7bit => YESNO
 
@@ -278,33 +220,20 @@ Default is C<"YES">.
 =back
 
 3-item list of (I<converted string>, I<charset for output>,
-I<transfer-encoding>) will be returned.
-I<Transfer-encoding> will be either C<"BASE64">, C<"QUOTED-PRINTABLE">,
+I<transfer-encoding>) is returned.
+C<Transfer-encoding> is either C<"BASE64">, C<"QUOTED-PRINTABLE">,
 C<"7BIT"> or C<"8BIT">.  If I<charset for output> could not be determined
-and I<converted string> contains non-ASCII byte(s), I<charset for output> will
-be C<undef> and I<transfer-encoding> will be C<"BASE64">.
-I<Charset for output> will be C<"US-ASCII"> if and only if string does not
-contain any non-ASCII bytes.
+and I<converted string> contains non-ASCII byte(s), I<charset for output> is
+C<undef> and I<transfer-encoding> is C<"BASE64">.  I<Charset for output> is
+C<"US-ASCII"> if and only if string doesn't contain any non-ASCII bytes.
 
 =cut
 
 sub body_encode {
-    my ($encoded, $charset, $cset) = &_text_encode(@_);
+    my ($encoded, $charset, $cset) = &text_encode(@_);
 
     # Determine transfer-encoding.
-    my $enc;
-    my $dummy = $encoded;
-    eval {
-	from_to($dummy, $cset, "US-ASCII", FB_CROAK());
-    };
-    if (!$@ and $dummy eq $encoded) {
-	$cset = "US-ASCII";
-	$enc = undef;
-    } else {
-	$@ = '';
-	$enc = &body_encoding($charset);
-    }
-
+    my $enc = &body_encoding($charset);
     if (!$enc and $encoded !~ /\x00/) {	# Eliminate hostile NUL character.
         if ($encoded =~ $NONASCIIRE) {	# String contains 8bit char(s).
             $enc = '8BIT';
@@ -324,61 +253,19 @@ sub body_encode {
     return ($encoded, $cset, $enc);
 }
 
-=item encoded_header_len STRING, ENCODING, CHARSET
-
-Get length of encoded STRING for message header
-(without folding).
-
-ENCODING may be one of C<"B">, C<"Q"> or C<"S"> (shorter
-one of either C<"B"> or C<"Q">).
-
-=cut
-
-sub encoded_header_len($$$) {
-    my $s = shift;
-    my $encoding = uc(shift);
-    my $charset  = shift;
-
-    my $enclen;
-    if ($encoding eq 'Q') {
-        $enclen = _enclen_Q($s);
-    } elsif ($encoding eq "S") {
-        my ($b, $q) = (_enclen_B($s), _enclen_Q($s));
-	$enclen = ($b < $q)? $b: $q;
-    } else { # "B"
-        $enclen = _enclen_B($s);
-    }
-
-    length($charset)+$enclen+7;
-}
-
-sub _enclen_B($) {
-    int((length(shift) + 2) / 3) * 4;
-}
-
-sub _enclen_Q($) {
-    my $s = shift;
-    my @o;
-    @o = ($s =~ /(\?|=|_|[^ \x21-\x7e])/gos);
-    length($s) + scalar(@o) * 2;
-}
-
 =item header_encode STRING, CHARSET [, OPTS]
 
-Get converted (if needed) data of STRING and recommended encoding scheme of
+Get converted (if needed) data and recommended encoding scheme of
 that data for message headers.  CHARSET is the charset by which STRING
 is encoded.
 
-OPTS may accept following key-value pairs.
-B<NOTE>:
-When Unicode/multibyte support is disabled (see L<"USE_ENCODE">),
-conversion will not be performed.  So these options do not have any effects.
+OPTS may accept following key-value pairs:
 
 =over 4
 
 =item Replacement => REPLACEMENT
 
-Specifies error handling scheme.  See L<"ERROR HANDLING">.
+Specifies error handling scheme. See L<ERROR HANDLING>.
 
 =item Detect7bit => YESNO
 
@@ -388,44 +275,31 @@ Default is C<"YES">.
 =back
 
 3-item list of (I<converted string>, I<charset for output>,
-I<encoding scheme>) will be returned.  I<Encoding scheme> will be
-either C<"B">, C<"Q"> or C<undef> (might not be encoded).
-If I<charset for output> could not be determined and I<converted string>
-contains non-ASCII byte(s), I<charset for output> will be C<"8BIT">
-(this is I<not> charset name but a special value to represent unencodable
-data) and I<encoding scheme> will be C<undef> (should not be encoded).
-I<Charset for output> will be C<"US-ASCII"> if and only if string does not
-contain any non-ASCII bytes.
+I<encoding scheme>) is returned.  I<Encoding scheme> is either C<"B">,
+C<"Q"> or C<undef> (might not be encoded).  If I<charset for output>
+could not be determined and I<converted string> contains non-ASCII byte(s),
+I<charset for output> is C<"8BIT"> (this is I<not> charset name but a
+special value to represent unencodable data) and I<encoding scheme> is
+C<undef> (shouldn't be encoded).  I<Charset for output> is C<"US-ASCII">
+if and only if string doesn't contain any non-ASCII bytes.
 
 =back
 
 =cut
 
 sub header_encode {
-    my ($encoded, $charset, $cset) = &_text_encode(@_);
+    my ($encoded, $charset, $cset) = &text_encode(@_);
     return ($encoded, '8BIT', undef) unless $cset;
 
     # Determine encoding scheme.
-    my $enc;
-    my $dummy = $encoded;
-    eval {
-	from_to($dummy, $cset, "US-ASCII", FB_CROAK());
-    };
-    if (!$@ and $dummy eq $encoded) {
-	$cset = "US-ASCII";
-	$enc = undef;
-    } else {
-	$@ = '';
-	$enc = &header_encoding($charset);
-    }
-
+    my $enc = &header_encoding($charset);
     if (!$enc and $encoded !~ $NONASCIIRE) {
 	unless ($cset =~ $ISO2022RE) {	# ISO-2022-* outputs are 7BIT.
             $cset = 'US-ASCII';
         }
     } elsif ($enc eq 'S') {
-	if (&encoded_header_len($encoded, "B", $cset) <
-	    &encoded_header_len($encoded, "Q", $cset)) {
+	if (length(Encode::encode("MIME-B", $encoded)) <
+	    length(Encode::encode("MIME-Q", $encoded))) {
 	    $enc = 'B';
 	} else {
 	    $enc = 'Q';
@@ -436,7 +310,7 @@ sub header_encode {
     return ($encoded, $cset, $enc);
 }
 
-sub _text_encode {
+sub text_encode {
     my $s = shift;
     my $charset = &canonical_charset(shift);
     my %params = @_;
@@ -447,7 +321,7 @@ sub _text_encode {
 	if ($s =~ $NONASCIIRE) {
 	    return ($s, undef, undef);
 	} elsif ($detect7bit ne "NO") {
-	    $charset = &_detect_7bit_charset($s);
+	    $charset = &detect_7bit_charset($s);
 	} else {
 	    $charset = $DEFAULT_CHARSET;
 	} 
@@ -455,62 +329,62 @@ sub _text_encode {
 
     # Unknown charset.
     return ($s, $charset, $charset)
-	unless resolve_alias($charset);
+	unless Encode::resolve_alias($charset);
 
     # Encode data by output charset if required.  If failed, fallback to
     # fallback charset.
     my $cset = &output_charset($charset);
     my $encoded;
 
-    if (is_utf8($s) or $s =~ /[^\x00-\xFF]/) {
+    if (Encode::is_utf8($s)) {
 	if ($replacement =~ /^(?:CROAK|STRICT|FALLBACK)$/) {
 	    eval {
-		$encoded = $s;
-		$encoded = encode($cset, $encoded, FB_CROAK());
+		$encoded = Encode::encode($cset, $s, $Encode::FB_CROAK);
 	    };
 	    if ($@) {
 		if ($replacement eq "FALLBACK" and $FALLBACK_CHARSET) {
 		    $cset = $FALLBACK_CHARSET;
-		    $encoded = $s;
-		    $encoded = encode($cset, $encoded);
+		    $encoded = Encode::encode($cset, $s);
 		    $charset = $cset;
 		} else {
 		    croak $@;
 		}
 	    }
 	} elsif ($replacement eq "PERLQQ") {
-	    $encoded = encode($cset, $s, FB_PERLQQ());
+	    $encoded = Encode::encode($cset, $s, $Encode::FB_PERLQQ);
 	} elsif ($replacement eq "HTMLCREF") {
-	    $encoded = encode($cset, $s, FB_HTMLCREF());
+	    $encoded = Encode::encode($cset, $s, $Encode::FB_HTMLCREF);
 	} elsif ($replacement eq "XMLCREF") {
-	    $encoded = encode($cset, $s, FB_XMLCREF());
+	    $encoded = Encode::encode($cset, $s, $Encode::FB_XMLCREF);
 	} else {
-	    $encoded = encode($cset, $s);
+	    $encoded = Encode::encode($cset, $s);
 	}
     } elsif ($charset ne $cset) {
 	$encoded = $s;
 	if ($replacement =~ /^(?:CROAK|STRICT|FALLBACK)$/) {
 	    eval {
-		from_to($encoded, $charset, $cset, FB_CROAK());
+		&Encode::from_to($encoded, $charset, $cset, $Encode::FB_CROAK);
 	    };
 	    if ($@) {
 		if ($replacement eq "FALLBACK" and $FALLBACK_CHARSET) {
 		    $cset = $FALLBACK_CHARSET;
-		    $encoded = $s;
-		    from_to($encoded, $charset, $cset);
+		    Encode::from_to($encoded, $charset, $cset);
 		    $charset = $cset;
 		} else {
 		    croak $@;
 		}
 	    }
         } elsif ($replacement eq "PERLQQ") {
-            from_to($encoded, $charset, $cset, FB_PERLQQ());
+            Encode::from_to($encoded, $charset, $cset,
+				       $Encode::FB_PERLQQ);
         } elsif ($replacement eq "HTMLCREF") {
-            from_to($encoded, $charset, $cset, FB_HTMLCREF());
+            Encode::from_to($encoded, $charset, $cset,
+				       $Encode::FB_HTMLCREF);
         } elsif ($replacement eq "XMLCREF") {
-            from_to($encoded, $charset, $cset, FB_XMLCREF());
+            Encode::from_to($encoded, $charset, $cset,
+				       $Encode::FB_XMLCREF);
         } else {
-            from_to($encoded, $charset, $cset);
+            Encode::from_to($encoded, $charset, $cset);
         }
     } else {
         $encoded = $s;
@@ -519,8 +393,7 @@ sub _text_encode {
     return ($encoded, $charset, $cset);
 }
 
-sub _detect_7bit_charset($) {
-    return $DEFAULT_CHARSET unless USE_ENCODE;
+sub detect_7bit_charset($) {
     my $s = shift;
     return $DEFAULT_CHARSET unless $s;
 
@@ -529,8 +402,7 @@ sub _detect_7bit_charset($) {
 	my ($seq, $cset) = @$_;
 	if (index($s, $seq) >= 0) {
             eval {
-		my $dummy = $s;
-		decode($cset, $dummy, FB_CROAK());
+		my $dummy = Encode::decode($cset, $s, $Encode::FB_CROAK);
 	    };
 	    if ($@) {
 		next;
@@ -544,18 +416,18 @@ sub _detect_7bit_charset($) {
     return $DEFAULT_CHARSET;
 }
 
-=head2 MANIPULATING MODULE DEFAULTS
+=head2 MANUPULATING PACKAGE DEFAULTS
 
 =over 4
 
 =item alias ALIAS [, CHARSET]
 
 Get/set charset alias for canonical names determined by
-L<"canonical_charset">.
+L<canonical_charset>.
 
-If CHARSET is given and isn't false, ALIAS will be assigned as an alias of
-CHARSET.  Otherwise, alias won't be changed.  In both cases,
-current charset name that ALIAS is assigned will be returned.
+If CHARSET is given and not false, ALIAS is assigned as an alias of
+CHARSET.  Otherwise, alias is not changed.  In both cases, this
+function returns current charset name that ALIAS is assigned.
 
 =cut
 
@@ -573,16 +445,16 @@ sub alias ($;$) {
 
 Get/set default charset.
 
-B<Default charset> is used by this module when charset context is
-unknown.  Modules using this module are recommended to use this
+B<Default charset> is used by this package when charset context is
+unknown.  Modules using this package are recommended to use this
 charset when charset context is unknown or implicit default is
 expected.  By default, it is C<"US-ASCII">.
 
-If CHARSET is given and isn't false, it will be set to default charset.
-Otherwise, default charset won't be changed.  In both cases,
-current default charset will be returned.
+If CHARSET is given and not false, it is set to default charset.
+Otherwise, default charset is not changed.  In both cases, this
+function returns current default charset.
 
-B<NOTE>: Default charset I<should not> be changed.
+B<Note>: Default charset should not be changed.
 
 =cut
 
@@ -591,7 +463,7 @@ sub default(;$) {
 
     if ($charset) {
 	croak "Unknown charset '$charset'"
-	    unless resolve_alias($charset);
+	    unless Encode::resolve_alias($charset);
 	$DEFAULT_CHARSET = $charset;
     }
     return $DEFAULT_CHARSET;
@@ -601,15 +473,15 @@ sub default(;$) {
 
 Get/set fallback charset.
 
-B<Fallback charset> is used by this module when conversion by given
+B<Fallback charset> is used by this package when conversion by given
 charset is failed and C<"FALLBACK"> error handling scheme is specified.
-Modules using this module may use this charset as last resort of charset
+Modules using this package may use this charset as last resort of charset
 for conversion.  By default, it is C<"UTF-8">.
 
-If CHARSET is given and isn't false, it will be set to fallback charset.
-If CHARSET is C<"NONE">, fallback charset will be undefined.
-Otherwise, fallback charset won't be changed.  In any cases,
-current fallback charset will be returned.
+If CHARSET is given and not false, it is set to fallback charset.
+If CHARSET is C<"NONE">, fallback charset become undefined.
+Otherwise, fallback charset is not changed.  In any cases, this
+function returns current fallback charset.
 
 B<NOTE>: It I<is> useful that C<"US-ASCII"> is specified as fallback charset,
 since result of conversion will be readable without charset informations.
@@ -623,7 +495,7 @@ sub fallback(;$) {
 	$FALLBACK_CHARSET = undef;
     } elsif ($charset) {
 	croak "Unknown charset '$charset'"
-	    unless resolve_alias($charset);
+	    unless Encode::resolve_alias($charset);
 	$FALLBACK_CHARSET = $charset;
     }
     return $FALLBACK_CHARSET;
@@ -634,8 +506,8 @@ sub fallback(;$) {
 Get/set charset profiles.
 
 If optional arguments are given and any of them are not false, profiles
-for CHARSET will be set by those arguments.  Otherwise, profiles
-won't be changed.  In both cases, current profiles for CHARSET will be
+for CHARSET is set by those arguments.  Otherwise, profiles
+won't be changed.  In both cases, current profiles for CHARSET are
 returned as 3-item list of (HEADERENC, BODYENC, ENCCHARSET).
 
 HEADERENC is recommended encoding scheme for message header.
@@ -645,16 +517,15 @@ C<undef> (might not be encoded).
 BODYENC is recommended transfer-encoding for message body.  It may be
 one of C<"B">, C<"Q"> or C<undef> (might not be transfer-encoded).
 
-ENCCHARSET is a charset which is compatible with given CHARSET and
-is recommended to be used for MIME messages on Internet.
-If conversion is not needed (or this module doesn't know appropriate
-charset), ENCCHARSET is C<undef>.
+ENCCHARSET is compatible with given CHARSET and is recommended to be
+used for MIME messages on Internet.  If conversion is not needed
+(or this package doesn't know appropriate charset), ENCCHARSET is
+C<undef>.
 
 B<NOTE>: This function in the future releases can accept more optional
-arguments (for example, properties to handle character widths, line folding
-behavior, ...).  So format of returned value may probably be changed.
-Use L<"header_encoding">, L<"body_encoding"> or L<"output_charset"> to get
-particular profile.
+arguments (for example, properties for line folding).  So format of
+returned value may probably be changed.  Use L<header_encoding>,
+L<body_encoding> or L<output_charset> to get particular profile.
 
 =cut
 
@@ -670,31 +541,22 @@ sub recommended ($;$;$;$) {
 
     if ($henc or $benc or $cset) {
 	$cset = undef if $charset eq $cset;
-	my @spec = ($henc, $benc, USE_ENCODE? $cset: undef);
+	my @spec = ($henc, $benc, $cset);
 	$CHARSETS{$charset} = \@spec;
 	return @spec;
     } else {
 	my $spec = $CHARSETS{$charset};
 	if ($spec) {
-	    return ($$spec[0], $$spec[1], USE_ENCODE? $$spec[2]: undef);
+	    return ($$spec[0], $$spec[1], $$spec[2]);
 	} else {
 	    return ('S', 'B', undef);
 	}
     }
 }
 
-=head2 CONSTANTS
-
-=item USE_ENCODE
-
-Unicode/multibyte support flag.
-Non-null string will be set when Unicode and multibyte support is enabled.
-Currently, this flag will be non-null on Perl 5.8.1 or later and
-null string on earlier versions of Perl.
-
 =head2 ERROR HANDLING
 
-L<"body_encode"> and L<"header_encode"> accept following C<Replacement>
+L<body_encode> and L<header_encode> accept following C<Replacement>
 options:
 
 =item C<"DEFAULT">
@@ -704,7 +566,7 @@ For UCM-based encodings, <subchar> will be used.
 
 =item C<"FALLBACK">
 
-Try C<"DEFAULT"> scheme using I<fallback charset> (see L<"fallback">).
+Try C<"DEFAULT"> scheme using I<fallback charset> (see L<fallback>).
 When fallback charset is undefined and conversion causes error,
 code will die on error with an error message.
 
@@ -721,8 +583,8 @@ Synonym is C<"STRICT">.
 
 =item C<"XMLCREF">
 
-Use C<FB_PERLQQ>, C<FB_HTMLCREF> or C<FB_XMLCREF>
-scheme defined by L<Encode> module.
+Use L<FB_PERLQQ>, L<FB_HTMLCREF> or L<FB_XMLCREF> scheme defined by
+L<Encode> module.
 
 =back
 
@@ -733,12 +595,35 @@ C<"DEFAULT"> will be assumed.
 
 Multipurpose Internet Mail Extensions (MIME).
 
-=head1 AUTHORS
+=head1 COPYRIGHT
 
-Copyright (C) 2006 Hatuka*nezumi - IKEDA Soji <hatuka(at)nezumi.nu>.
+Copyright (C) 2006 Hatuka*nezumi - IKEDA Soji <F<hatuka@nezumi.nu>>.
+All rights reserved.
 
-All rights reserved.  This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
+=head1 LICENSE
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of either:
+
+a) the GNU General Public License as published by the Free Software
+Foundation; either version 1, or (at your option) any later version,
+
+or
+
+b) the "Artistic License" which comes with this module.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either
+the GNU General Public License or the Artistic License for more details.
+
+You should have received a copy of the Artistic License with this
+module, in the file ARTISTIC.  If not, I'll be glad to provide one.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+USA.
 
 =cut
 
